Skip to content
KitploitKITPLOIT
StrumentiBlog
Log in
Invia
StrumentiBlog
Invia

Strumenti di Hacking, PenTest e Cybersecurity per il tuo Arsenale di Sicurezza!

Kitploit è una directory di strumenti di hacking, cybersecurity e pentesting. Scopri gli ultimi aggiornamenti dei progetti per trovare vulnerabilità, analizzare sistemi, automatizzare i test e rafforzare la tua sicurezza.

··Feed·Contatto·Privacy·© 2026 Kitploit

Directory degli strumenti

Categorie

Vedi tutte le categorie
Loading categories
mapcidr — Programma utility per eseguire più operazioni per una data subnet/intervalli CIDR. | Kitploit
Strumenti/GitHubGitHub/projectdiscovery/mapcidr
RicognizioneMappatura della ReteRaccolta InformazioniUtilità e Framework
GitHubprojectdiscovery/mapcidr

mapcidr

Programma utility per eseguire più operazioni per una data subnet/intervalli CIDR.

Vedi Repository
1.2k1117822h 50m faRevisionato da Kitploit

Più Popolari

Vedi tutti →

Scopri gli strumenti più utilizzati dalla nostra community.

Esplora tutti gli strumenti

Sfoglia la nostra collezione di strumenti

Vedi tutti gli strumenti →
Condividi
Sito web

mapCIDR

Un programma di utilità per eseguire multiple operazioni su una data sottorete/intervallo CIDR.

Caratteristiche • Installazione • Utilizzo • Libreria • Unisciti a Discord


mapCIDR è stato sviluppato per facilitare la distribuzione del carico nelle operazioni di scansione di massa; può essere utilizzato sia come libreria che come strumento CLI indipendente.

Caratteristiche

mapCIDR

  • Supporto per l'espansione CIDR (predefinito)
  • Supporto per il sezionamento CIDR (sbh, sbc)
  • Supporto per l'aggregazione CIDR/IP (a, aa)
  • Supporto per il matching CIDR/IP (match-ip)
  • Supporto per il filtraggio CIDR/IP (filter-ip)
  • Supporto per l'ordinamento CIDR/IP (s, sr)
  • Supporto per il conteggio host CIDR (count)
  • Supporto per formati IP multipli (ip-format)
  • Supporto per mescolamento IP/PORT (si, sp)
  • Supporto per conversione IPv4/IPv6 (t4, t6)
  • Supporto per input CIDR da STDIN (pipe)

Installazione

go install -v github.com/projectdiscovery/mapcidr/cmd/mapcidr@latest

Utilizzo

mapcidr -h

Questo mostrerà l'help dello strumento. Ecco tutti gli switch supportati.

INPUT:
   -cl, -cidr string[]  CIDR/IP/File contenente una lista di CIDR/IP da elaborare

PROCESS:
   -sbc int                  Seziona CIDR per conteggio CIDR specificato
   -sbh int                  Seziona CIDR per conteggio HOST specificato
   -a, -aggregate            Aggrega IP/CIDR nella sottorete minima
   -aa, -aggregate-approx    Aggrega IP/CIDR sparsi nella sottorete minima approssimata
   -c, -count                Conta il numero di IP in un dato CIDR
   -t4, -to-ipv4             Converte IP in formato IPv4
   -t6, -to-ipv6             Converte IP in formato IPv6
   -ip-format, -if string[]  Formati IP (0,1,2,3,4,5,6,7,8,9,10,11)
   -zpn, -zero-pad-n int     numero di zero di padding da utilizzare (default 3)
   -zpp, -zero-pad-permute   abilita permutazioni da 0 a zero-pad-n per ogni ottetto

FILTER:
   -f4, -filter-ipv4         Filtra IP IPv4 dall'input
   -f6, -filter-ipv6         Filtra IP IPv6 dall'input
   -skip-base                Salta IP base (che terminano con .0) nell'output
   -skip-broadcast           Salta IP broadcast (che terminano con .255) nell'output
   -mi, -match-ip string[]   IP/CIDR/FILE contenente una lista di IP/CIDR da confrontare (separati da virgola, input da file)
   -fi, -filter-ip string[]  IP/CIDR/FILE contenente una lista di IP/CIDR da filtrare (separati da virgola, input da file)

MISCELLANEOUS:
   -s, -sort                  Ordina IP/CIDR in input in ordine crescente
   -sr, -sort-reverse         Ordina IP/CIDR in input in ordine decrescente
   -si, -shuffle-ip           Mescola IP in input in ordine casuale
   -sp, -shuffle-port string  Mescola IP:Port in input in ordine casuale

UPDATE:
   -up, -update                 aggiorna mapcidr all'ultima versione
   -duc, -disable-update-check  disabilita il controllo automatico degli aggiornamenti
   
OUTPUT:
   -verbose            Modalità verbosa
   -o, -output string  File in cui scrivere l'output
   -silent             Modalità silenziosa
   -version            Mostra la versione del progetto

Esecuzione di mapCIDR

Per ottenere una lista di IP per un dato CIDR, usa il seguente comando:

Espansione CIDR

mapcidr -cidr 173.0.84.0/24
                   ____________  ___    
  __ _  ___ ____  / ___/  _/ _ \/ _ \
 /  ' \/ _ '/ _ \/ /___/ // // / , _/   
/_/_/_/\_,_/ .__/\___/___/____/_/|_| v0.5
          /_/                                                     	 

		projectdiscovery.io

[WRN] Use with caution. You are responsible for your actions
[WRN] Developers assume no liability and are not responsible for any misuse or damage.

173.0.84.0
173.0.84.1
173.0.84.2
173.0.84.3
173.0.84.4
173.0.84.5
173.0.84.13
173.0.84.14
173.0.84.15
173.0.84.16

È anche possibile ottenere una lista di IP per un dato intervallo IP, usando il seguente comando:

$ echo "192.168.0.0-192.168.0.5" | mapcidr
192.168.0.0
192.168.0.1
192.168.0.2
192.168.0.3
192.168.0.4
192.168.0.5

Sezionamento CIDR per Conteggio CIDR

Per sezionare un dato CIDR o una lista di CIDR per conteggio CIDR o per sezionare in più sottoreti più piccole e uguali, usa il seguente comando:

mapcidr -cidr 173.0.84.0/24 -sbc 10 -silent
173.0.84.0/27
173.0.84.32/27
173.0.84.64/27
173.0.84.96/27
173.0.84.128/27
173.0.84.160/27
173.0.84.208/28
173.0.84.192/28
173.0.84.240/28
173.0.84.224/28

Sezionamento CIDR per Conteggio HOST

Per sezionare il dato CIDR in un numero uguale di host in ciascun CIDR, usa il seguente comando:

mapcidr -cidr 173.0.84.0/16 -sbh 20000 -silent
173.0.0.0/18
173.0.64.0/18
173.0.128.0/18
173.0.192.0/18

Nota: È possibile ottenere una suddivisione perfetta solo quando il numero desiderato di sezioni o di host per sottorete è una potenza di due. Altrimenti, lo strumento tenterà di trovare automaticamente la migliore strategia di suddivisione per ottenere il risultato desiderato.

Aggregazione CIDR/IP

Per unire più intervalli CIDR in un blocco di sottorete più piccolo, usa il seguente comando:

$ mapcidr -cl cidrs.txt -aggregate

Per elencare i blocchi CIDR per una data lista di IP, usa il seguente comando:

$ mapcidr -il ips.txt -aggregate

È anche possibile eseguire aggregazioni approssimate per gruppi IP sparsi (solo versione 4). L'intervallo finale conterrà IP contigui non appartenenti all'input:

$ cat ips.txt 

1.1.1.1
1.1.1.16
1.1.1.31
$ cat ips.txt | mapcidr -aggregate-approx

1.1.1.0/27

Per elencare i blocchi CIDR per un dato intervallo IP (IPv4 | IPv6), usa il seguente comando:

 $ mapcidr  -cl 192.168.0.1-192.168.0.255 -aggregate
 OPPURE
 $ echo 192.168.0.1-192.168.0.255 | mapcidr -aggregate
192.168.0.1/32
192.168.0.2/31
192.168.0.4/30
192.168.0.8/29
192.168.0.16/28
192.168.0.32/27
192.168.0.64/26
192.168.0.128/25

Corrispondenza / Filtraggio IP da CIDR

Per trovare IP corrispondenti dalla lista data di intervalli CIDR, usa il seguente comando:

$ mapcidr -cidr 192.168.1.0/24 -mi 192.168.1.253,192.168.1.252
$ mapcidr -cidr 192.168.1.0/24 -mi ip_list_to_match.txt

Per filtrare IP dalla lista data di intervalli CIDR, usa il seguente comando:

$ mapcidr -cidr 192.168.1.224/28 -fi 192.168.1.233,192.168.1.234
$ mapcidr -cidr 192.168.1.224/28 -fi ip_list_to_filter.txt

Formati IP

Scarica lo strumento